# $Header: /home/cvsroot/zSQLgate/DBIServer/MARC.pm,v 1.2 2004/11/13 00:52:56 mike Exp $

package Net::Z3950::DBIServer::MARC;
use MARC::Record;
use strict;

=head1 NAME

Net::Z3950::DBIServer::MARC - build MARC records for DBIServer

=head1 SYNOPSIS

	$rec = Net::Z3950::DBIServer::MARC::format(
		{ title=>'Mr', forename=>'Eric', surname=>'1/2 Bee' },
		$config);

=head1 DESCRIPTION

This non-OO module exists only to provide a single function which
formats a set of fields as a MARC record.

=head1 METHODS

=head2 format()

	$rec = Net::Z3950::DBIServer::MARC::format($hashref, $config);

Creates and returns, as an unblessed string, a new MARC record
containing the specified fields according to the configuration
specified in the database-and-record-syntax-specific configuration
segment I<$config>, of type C<Net::Z3950::DBIServer::Config::XMLSpec>.

=cut

sub format {
    my($hashref, $config) = @_;

    my %fields;
    foreach my $field ($config->fieldNames()) {
	my $sqlField = $config->fieldSpec($field)->columnName();
	my $data = Net::Z3950::DBIServer::XML::make_data($sqlField, $hashref);
	next if !defined $data || $data eq "";

	my($tag, $i1, $i2, $subtag) = ($field, "", "");
	if ($tag =~ s/\$(.*)//) {
	    $subtag = $1;
	}
	if ($tag =~ s/\/(.*)//) {
	    $i1 = $1;
	    if ($i1 =~ s/\/(.*)//) {
		$i2 = $1;
	    }
	}

	if ($tag =~ /^00/) {
	    $fields{$tag} = MARC::Field->new($tag, $data);
	} elsif (defined $fields{$tag}) {
	    $fields{$tag}->add_subfields($subtag => $data);
	} else {
	    $fields{$tag} = MARC::Field->new($tag, $i1, $i2, $subtag => $data);
	}
    }

    my $rec = new MARC::Record();
    my $leader = $config->recordName();
    $rec->leader($leader) if defined $leader;
    $rec->append_fields(map { $fields{$_} } sort keys %fields);

    if (1) {
	open X, ">/tmp/xx";
	print X $rec->as_usmarc();
	close X;
    }

    return $rec->as_usmarc();
}


=head1 AUTHOR

Mike Taylor E<lt>mike@miketaylor.org.ukE<gt>

First version Thursdat 11th November 2004.

=head1 SEE ALSO

C<Net::Z3950::DBIServer>
is the module that uses this.

=cut


1;
